/*!
    Copyright 2017 Kuromatch
*/
import "../css/kuromaty.less";
import { PositionLike } from "./Position";
import { OrderLike } from "./Order";
import * as overlays from "./overlays/";
import { Candle, Candles } from "./CandleStore";
import { EventEmitter } from "eventemitter3";
import { LinkConfig } from "./components/LinkConfig";
import { ConnectionStatus, RequestStatus } from "./components/Footer";
import { OverlayMap, OverlayModule } from "./OverlayModule";
import { i18n } from "i18next";
export interface Config {
    cursorSnapToGrid: boolean;
    enableBoard: boolean;
    boardGroupSize: number;
    pricePopEffect: boolean;
    supportHighDPI: boolean;
    enableOrderAndPositionMarkers: boolean;
    powerSaveMode: boolean;
    limitHorizontalScrolling: boolean;
}
export interface Options {
    barWidth?: number;
    barMargin?: number;
    decimalPower?: number;
    quickOrder?: boolean;
    quickOrderHandler?: (order: QuickOrder) => void;
    hideBoardControl?: boolean;
    hideOrderAndPositionMarkerControl?: boolean;
    powerSaveMode?: boolean;
    title?: string;
    headerLinks?: LinkConfig[];
    brand?: string;
    version?: string;
    timePeriod?: number;
    maxBarCount?: number;
    i18n?: i18n;
}
export interface QuickOrder {
    price: number;
    type: "limit" | "stop-limit";
}
export interface ColorOption {
    bg?: string;
    text?: string;
    textStrong?: string;
    textWeak?: string;
    short?: string;
    long?: string;
    askOrder?: string;
    bidOrder?: string;
    volume?: string;
    askDepth?: string;
    bidDepth?: string;
    askDepthLast?: string;
    bidDepthLast?: string;
    grid?: string;
    border?: string;
    borderText?: string;
    borderLTP?: string;
    borderLTPText?: string;
    lineMA1?: string;
    lineMA2?: string;
    lineMA3?: string;
    lineBand?: string;
    lineCE?: string;
}
export interface TickerExtra {
    bestBid?: number;
    bestAsk?: number;
    time: number;
}
export interface Board {
    asks: BoardItem[];
    bids: BoardItem[];
}
export interface BoardItem {
    price: number;
    size: number;
}
export interface Chart {
    canvas: HTMLCanvasElement;
    context: CanvasRenderingContext2D;
    _bars: Candles;
    range: number;
    highest: number;
    highestPrice: number;
    highestPricePrinted: boolean;
    lowest: number;
    lowestPrice: number;
    lowestPricePrinted: boolean;
    askPrice: number;
    bidPrice: number;
    maxVolume: number;
    volumeRatio: number;
    maxDepth: number;
    minDepth: number;
    depthRatio: number;
    latest: number;
    ratio: number;
    tickDelta: number;
}
export interface InLayer {
    canvas: HTMLCanvasElement;
    context: CanvasRenderingContext2D;
}
export declare type Position = PositionLike;
export declare class Kuromaty extends EventEmitter {
    readonly options: Options;
    static readonly overlays: typeof overlays;
    static overlayModules: OverlayModule[];
    barIndex: number;
    cursorPrice: number;
    cursorBoard: number;
    cursorBoardPrice: number;
    pinnedPrices: number[];
    color: ColorOption;
    cursorX: number;
    cursorY: number;
    canvasW: number;
    canvasH: number;
    chart: Chart;
    overlay: InLayer;
    grid: InLayer;
    canvases: HTMLCanvasElement[];
    contexts: CanvasRenderingContext2D[];
    overlays: OverlayMap;
    private _dpr;
    private _rootContainer;
    private _mainContainer;
    private _chartContainer;
    private _header;
    private _footer;
    private _controls;
    private _hasUpdated;
    private _hasRemoved;
    private _hasConnected;
    private _cancelDraw;
    private _afs;
    private _pricePops;
    private _lastPointerdown;
    private _lastPointerType;
    private _lastPointerButtons;
    private _dragStartX;
    private _dragStartI;
    private _decimal;
    private _cursorStep;
    private _positions;
    private _orders;
    private _contextMenu;
    private _candleStore;
    private _boardStore;
    private _sleepDetector;
    private _config;
    private _timePeriod;
    private _isActive;
    private _i18n;
    private __keydownHandler;
    constructor(container?: Element, options?: Options);
    insertTo(container: Element): void;
    remove(): void;
    resize(): void;
    zoom(delta: number): void;
    addOHLC(period: number, theirs: Candle[]): void;
    tick(tick: Candle, ex: TickerExtra): void;
    updateBoard(board: Board): void;
    setConnectionStatus(status: ConnectionStatus): void;
    setConnectionStatusTooltip(html: string): void;
    setRequestStatus(status: RequestStatus): void;
    setBoardSnapshot(board: Board): void;
    setColor(option: ColorOption): void;
    setPositions(positions: PositionLike[]): void;
    setOrders(orders: OrderLike[]): void;
    readonly config: Readonly<Config>;
    readonly timePeriod: number;
    readonly ltp: number;
    private _create;
    private _addListeners;
    private _removeListeners;
    private _initControls;
    private _updateDpr;
    private _redraw;
    private _draw;
    private getRequiredBackCount;
    private getRequiredForwardCount;
    private _drawPricePopEffect;
    private _keydownHandler;
    private _contextmenuHandler;
    private _touchEventsHandler;
    private _pointerdownHandler;
    private _pointerupHandler;
    private _togglePinnedPrice;
    private _pointermoveHandler;
    private _pointeroutHandler;
    private _wheelHandler;
    private _drawBorder;
    private _drawVerticalRange;
    private _drawPriceTag;
    private _drawPriceTag2;
    private _drawDepthIndicator;
    private _drawPositionMarker;
    private _drawOrderMarker;
    private _getMaxIndex;
    private _getMinIndex;
    private _resetBarIndex;
    private _fixBarIndex;
    private calculateHorizontalGridLowestPrice;
}
export default Kuromaty;
